==> multicurrency-0.2.0-py3-none-any.whl: multicurrency/dram.py <==
# -*- coding: UTF-8 -*-
#
# copyright: 2020-2021, Frederico Martins
# author: Frederico Martins <http://github.com/fscm>
# license: SPDX-License-Identifier: MIT

"""Dram currency representation(s)."""

from decimal import Decimal
from typing import Optional, Union
from .currency import Currency


class ArmenianDram(Currency):
    """Armenian Dram currency representation.

    Simple usage example:

        >>> from multicurrency import ArmenianDram
        >>> armenian_dram = ArmenianDram(amount=1)
        >>> print(armenian_dram)
        Դ1.00

    For more details see `multicurrency.currency.Currency` .

    Args:
        amount (Union[int, float, Decimal]): Represented value.
        decimal_places (int, optional): Number of decimal places for the
            currency representation. Defaults to 2,
        decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
        grouping_sign (str, optional): Grouping symbol. Defaults to ','.
        international (bool, optional): Identifies the currency using
            the 'currency' value instead of the 'symbol'. Defaults to
            False.
    """

    __slots__ = []

    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
            cls,
            amount: Union[int, float, Decimal],
            decimal_places: int = 2,
            decimal_sign: Optional[str] = '.',
            grouping_sign: Optional[str] = ',',
            international: bool = False,
            **other) -> 'ArmenianDram':
        """Class creator.

        Returns:
            ArmenianDram: new opbject.
        """
        return Currency.__new__(
            cls,
            amount=amount,
            currency='AMD',
            symbol='Դ',
            code='051',
            decimal_places=decimal_places,
            decimal_sign=decimal_sign,
            grouping_sign=grouping_sign,
            international=international)

==> multicurrency-0.3.0-py3-none-any.whl: multicurrency/dram.py <==
# -*- coding: UTF-8 -*-
#
# copyright: 2020-2021, Frederico Martins
# author: Frederico Martins <http://github.com/fscm>
# license: SPDX-License-Identifier: MIT

"""Dram currency representation(s)."""

from decimal import Decimal
from typing import Optional, Union
from .currency import Currency


class ArmenianDram(Currency):
    """Armenian Dram currency representation.

    Simple usage example:

        >>> from multicurrency import ArmenianDram
        >>> armenian_dram = ArmenianDram(
        ...     amount=123456.789)
        >>> print(armenian_dram)
        123 456,79 Դ

    For more details see `multicurrency.currency.Currency` .

    Args:
        amount (Union[int, float, Decimal]): Represented value.
        decimal_places (int, optional): Number of decimal places for the
            currency representation. Defaults to 2,
        decimal_sign (str, optional): Decimal symbol. Defaults to ','.
        grouping_sign (str, optional): Grouping symbol. Defaults to ' '.
        international (bool, optional): Identifies the currency using
            the 'currency' value instead of the 'symbol'. Defaults to
            False.
        symbol_separator (str, optional): Separation between the symbol
            and the value. Defaults to ' '.
        symbol_ahead (bool, optional): True if symbol goes ahead of the
            value. False otherwise. Defaults to False.
    """

    __slots__ = []

    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
            cls,
            amount: Union[int, float, Decimal],
            decimal_places: Optional[int] = 2,
            decimal_sign: Optional[str] = ',',
            grouping_sign: Optional[str] = '\u202F',
            international: Optional[bool] = False,
            symbol_ahead: Optional[bool] = False,
            symbol_separator: Optional[str] = '\u00A0',
            **other) -> 'ArmenianDram':
        """Class creator.

        Returns:
            ArmenianDram: new opbject.
        """
        return Currency.__new__(
            cls,
            amount=amount,
            alpha_code='AMD',
            numeric_code='051',
            symbol='Դ',
            symbol_separator=symbol_separator,
            symbol_ahead=symbol_ahead,
            decimal_places=decimal_places,
            decimal_sign=decimal_sign,
            grouping_sign=grouping_sign,
            international=international)
